@@ -22,19 +22,21 @@
 #include <config.h>
 #endif
 
+#include <stdint.h>
 #include <stdlib.h>
 #include <time.h>
+#include <unistd.h>
 
 #ifdef HAVE_RANDOM
 #include <random>
 #endif
 
+#include "ola/Clock.h"
 #include "ola/math/Random.h"
 
 namespace ola {
 namespace math {
 
-
 #ifdef HAVE_RANDOM
 std::default_random_engine generator_;
 #endif
@@ -43,12 +45,18 @@ std::default_random_engine generator_;
  * Seed the random number generator
  */
 void InitRandom() {
+  Clock clock;
+  TimeStamp now;
+  clock.CurrentTime(&now);
+
+  uint64_t seed = (static_cast<uint64_t>(now.MicroSeconds()) << 32) +
+                   static_cast<uint64_t>(getpid());
 #ifdef HAVE_RANDOM
-  generator_.seed(time(NULL));
+  generator_.seed(seed);
 #elif defined(_WIN32)
-  srand(time(NULL));
+  srand(seed);
 #else
-  srandom(time(NULL));
+  srandom(seed);
 #endif
 }
 
