@@ -75,6 +75,14 @@ class PidStoreTest: public CppUnit::TestFixture {
   void testPidStoreLoadDuplicateName();
   void testPidStoreLoadInvalidEstaPid();
   void testInconsistentData();
+
+ private:
+  string GetTestDataFile(const string &filename) {
+    string path = TEST_SRC_DIR;
+    path.append("/common/rdm/testdata/");
+    path.append(filename);
+    return path;
+  }
 };
 
 
@@ -316,12 +324,11 @@ void PidStoreTest::testPidStoreLoad() {
 void PidStoreTest::testPidStoreFileLoad() {
   PidStoreLoader loader;
 
-  auto_ptr<const RootPidStore> root_store(loader.LoadFromFile(
-      TEST_SRC_DIR "/testdata/test_pids.proto"));
+  auto_ptr<const RootPidStore> root_store(
+      loader.LoadFromFile(GetTestDataFile("test_pids.proto")));
   OLA_ASSERT_NOT_NULL(root_store.get());
   // check version
-  OLA_ASSERT_EQ(static_cast<uint64_t>(1302986774),
-                       root_store->Version());
+  OLA_ASSERT_EQ(static_cast<uint64_t>(1302986774), root_store->Version());
 
   // Check all the esta pids are there
   const PidStore *esta_store = root_store->EstaStore();
@@ -389,7 +396,7 @@ void PidStoreTest::testPidStoreDirectoryLoad() {
   PidStoreLoader loader;
 
   auto_ptr<const RootPidStore> root_store(loader.LoadFromDirectory(
-      TEST_SRC_DIR "/testdata/pids"));
+      GetTestDataFile("pids")));
   OLA_ASSERT_NOT_NULL(root_store.get());
   // check version
   OLA_ASSERT_EQ(static_cast<uint64_t>(1302986774),
@@ -436,7 +443,7 @@ void PidStoreTest::testPidStoreDirectoryLoad() {
 void PidStoreTest::testPidStoreLoadMissingFile() {
   PidStoreLoader loader;
   const RootPidStore *root_store = loader.LoadFromFile(
-      TEST_SRC_DIR "/testdata/missing_file_pids.proto");
+      GetTestDataFile("missing_file_pids.proto"));
   OLA_ASSERT_NULL(root_store);
 }
 
@@ -447,7 +454,7 @@ void PidStoreTest::testPidStoreLoadMissingFile() {
 void PidStoreTest::testPidStoreLoadDuplicateManufacturer() {
   PidStoreLoader loader;
   const RootPidStore *root_store = loader.LoadFromFile(
-      TEST_SRC_DIR "/testdata/duplicate_manufacturer.proto");
+      GetTestDataFile("duplicate_manufacturer.proto"));
   OLA_ASSERT_NULL(root_store);
 }
 
@@ -458,7 +465,7 @@ void PidStoreTest::testPidStoreLoadDuplicateManufacturer() {
 void PidStoreTest::testPidStoreLoadDuplicateValue() {
   PidStoreLoader loader;
   const RootPidStore *root_store = loader.LoadFromFile(
-      TEST_SRC_DIR "/testdata/duplicate_pid_value.proto");
+      GetTestDataFile("duplicate_pid_value.proto"));
   OLA_ASSERT_NULL(root_store);
 }
 
@@ -469,7 +476,7 @@ void PidStoreTest::testPidStoreLoadDuplicateValue() {
 void PidStoreTest::testPidStoreLoadDuplicateName() {
   PidStoreLoader loader;
   const RootPidStore *root_store = loader.LoadFromFile(
-      TEST_SRC_DIR "/testdata/duplicate_pid_name.proto");
+      GetTestDataFile("duplicate_pid_name.proto"));
   OLA_ASSERT_NULL(root_store);
 }
 
@@ -480,7 +487,7 @@ void PidStoreTest::testPidStoreLoadDuplicateName() {
 void PidStoreTest::testPidStoreLoadInvalidEstaPid() {
   PidStoreLoader loader;
   const RootPidStore *root_store = loader.LoadFromFile(
-      TEST_SRC_DIR "/testdata/invalid_esta_pid.proto");
+      GetTestDataFile("invalid_esta_pid.proto"));
   OLA_ASSERT_NULL(root_store);
 }
 
@@ -491,6 +498,6 @@ void PidStoreTest::testPidStoreLoadInvalidEstaPid() {
 void PidStoreTest::testInconsistentData() {
   PidStoreLoader loader;
   const RootPidStore *root_store = loader.LoadFromFile(
-      TEST_SRC_DIR "/testdata/inconsistent_pid.proto");
+      GetTestDataFile("inconsistent_pid.proto"));
   OLA_ASSERT_NULL(root_store);
 }
