@@ -11,11 +11,11 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * DmxBuffer.cpp
  * The DmxBuffer class
- * Copyright (C) 2005-2009 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  *
  * This implements a DmxBuffer which uses copy-on-write and delayed init.
  *
@@ -238,8 +238,8 @@ void DmxBuffer::SetChannel(unsigned int channel, uint8_t data) {
   }
 
   if (channel > m_length) {
-    OLA_WARN << "attempting to set channel " << channel << "when length is " <<
-      m_length;
+    OLA_WARN << "attempting to set channel " << channel << " when length is "
+             << m_length;
     return;
   }
 
@@ -311,7 +311,7 @@ string DmxBuffer::ToString() const {
   if (!m_data)
     return "";
 
-  std::stringstream str;
+  std::ostringstream str;
   for (unsigned int i = 0; i < Size(); i++) {
     if (i)
       str << ",";
