@@ -47,6 +47,7 @@
 #include <ola/DmxBuffer.h>
 #include <ola/OlaCallbackClient.h>
 #include <ola/OlaClientWrapper.h>
+#include <ola/base/Init.h>
 #include <ola/base/SysExits.h>
 #include <ola/io/SelectServer.h>
 
@@ -770,6 +771,11 @@ int main(int argc, char *argv[]) {
   signal(SIGWINCH, terminalresize);
   atexit(cleanup);
 
+  if (!ola::NetworkInit()) {
+    std::cerr << "Network initialization failed." << std::endl;
+    exit(ola::EXIT_UNAVAILABLE);
+  }
+
   // 10 bytes security, for file IO routines, will be optimized and checked
   // later
   dmx = reinterpret_cast<dmx_t*>(calloc(DMX_UNIVERSE_SIZE + 10,
