@@ -47,6 +47,7 @@
 #include <ola/OlaCallbackClient.h>
 #include <ola/OlaClientWrapper.h>
 #include <ola/DmxBuffer.h>
+#include <ola/base/Init.h>
 #include <ola/base/SysExits.h>
 #include <ola/io/SelectServer.h>
 
@@ -689,6 +690,11 @@ int main(int argc, char *argv[]) {
   signal(SIGWINCH, terminalresize);
   atexit(cleanup);
 
+  if (!ola::NetworkInit()) {
+    std::cerr << "Network initialization failed." << std::endl;
+    exit(ola::EXIT_UNAVAILABLE);
+  }
+
   options opts;
 
   ParseOptions(argc, argv, &opts);
