@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Flags.h
  * Command line flag (option) handling.
@@ -28,7 +28,7 @@
  * Features:
  *  - bool, uint8, uint16, uint32, int8, int16, int32 & string types.
  *  - short options (e.g. -x).
- *  - inverted bools, e.g. --nofoo
+ *  - inverted bools, e.g. --no-foo
  *
  * @note
  *   - Setting flags is not thread safe
@@ -80,7 +80,7 @@ namespace ola {
 /**
  * @brief Set the help string for the program.
  * @param first_line the inital line that is displayed in the help section.
- * This is displayed after argv[0].
+ *     This is displayed after argv[0].
  * @param description a multiline description of the program
  */
 void SetHelpString(const std::string &first_line,
@@ -91,6 +91,11 @@ void SetHelpString(const std::string &first_line,
  */
 void DisplayUsage();
 
+/**
+ * @brief Print the usage text to stdout then exit.
+ */
+void DisplayUsageAndExit();
+
 /**
  * @brief Print the version text to stdout.
  */
@@ -169,36 +174,77 @@ void ParseFlags(int *argc, char **argv);
 
 /**
  * @brief Create a new longname bool flag
+ *
+ * By default the flag is undefined, the same as the string and int ones, that
+ * is is_present() returns false. If the flag is provided on the command line,
+ * is_present() will be true, and operator bool() returns the value of the
+ * flag.
+ *
+ * @note The value must be parseable by StringToBoolTolerant.
  * @param name the name of the flag to create
- * @param default_value the default value for the flag.
- * Either true, or false.
+ * @param default_value the default value for the flag. Either true, or false.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_bool(name, default_value, help_str) \
-  DEFINE_flag(bool, name, \0, default_value, help_str)
+  DEFINE_flag(bool, name, \0, default_value, help_str, true)
 
 /**
- * @brief Create a new flag with a long and short name
- * @param name the full name of the flag to create
- * @param short_opt the short name of the flag. For example "-h", or "-d".
- * @param default_value the default value for the flag.
- * Either true, or false
+ * @brief Create a new bool flag with a long and short name
+ *
+ * By default the flag is undefined, the same as the string and int ones, that
+ * is is_present() returns false. If the flag is provided on the command line,
+ * is_present() will be true, and operator bool() returns the value of the
+ * flag.
+ *
+ * @note The value must be parseable by StringToBoolTolerant.
+ * @param name the name of the flag to create
+ * @param default_value the default value for the flag. Either true, or false.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_s_bool(name, short_opt, default_value, help_str) \
-  DEFINE_flag_with_short(bool, name, short_opt, default_value, help_str)
+  DEFINE_flag_with_short(bool, name, short_opt, default_value, help_str, true)
+
+/**
+ * @brief Create a new longname bool flag that doesn't require an argument.
+ *
+ * By default the flag is set to default_value. If the flag is provided on the
+ * command line, the value of the flag becomes !default_value.
+ *
+ * @param name the name of the flag to create
+ * @param default_value the default value for the flag. Either true, or false.
+ * @param help_str the string displayed when the program is asked to display
+ *     the help screen
+ */
+#define DEFINE_default_bool(name, default_value, help_str) \
+  DEFINE_flag(bool, name, \0, default_value, help_str, false)
+
+/**
+ * @brief Create a new bool flag with a long and short name that doesn't
+ *     require an argument.
+ *
+ * By default the flag is set to default_value. If the flag is provided on the
+ * command line, the value of the flag becomes !default_value.
+ *
+ * @param name the full name of the flag to create
+ * @param short_opt the short name of the flag. For example "-h", or "-d".
+ * @param default_value the default value for the flag. Either true, or false.
+ * @param help_str the string displayed when the program is asked to display
+ *     the help screen
+ */
+#define DEFINE_s_default_bool(name, short_opt, default_value, help_str) \
+  DEFINE_flag_with_short(bool, name, short_opt, default_value, help_str, false)
 
 /**
  * @brief Create a new longname int8_t flag
  * @param name the name of the flag to create
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_int8(name, default_value, help_str) \
-  DEFINE_flag(int8_t, name, \0, default_value, help_str)
+  DEFINE_flag(int8_t, name, \0, default_value, help_str, true)
 
 /**
  * @brief Create a new int8_t flag with a long and short name
@@ -206,20 +252,21 @@ void ParseFlags(int *argc, char **argv);
  * @param short_opt the short name of the flag. For example "-h", or "-d".
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_s_int8(name, short_opt, default_value, help_str) \
-  DEFINE_flag_with_short(int8_t, name, short_opt, default_value, help_str)
+  DEFINE_flag_with_short(int8_t, name, short_opt, default_value, help_str, \
+                         true)
 
 /**
  * @brief Create a new longname uint8_t flag
  * @param name the name of the flag to create
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_uint8(name, default_value, help_str) \
-  DEFINE_flag(uint8_t, name, \0, default_value, help_str)
+  DEFINE_flag(uint8_t, name, \0, default_value, help_str, true)
 
 /**
  * @brief Create a new uint8_t flag with a long and short name
@@ -227,20 +274,21 @@ void ParseFlags(int *argc, char **argv);
  * @param short_opt the short name of the flag. For example "-h", or "-d".
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_s_uint8(name, short_opt, default_value, help_str) \
-  DEFINE_flag_with_short(uint8_t, name, short_opt, default_value, help_str)
+  DEFINE_flag_with_short(uint8_t, name, short_opt, default_value, help_str, \
+                         true)
 
 /**
  * @brief Create a new longname int16_t flag
  * @param name the name of the flag to create
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_int16(name, default_value, help_str) \
-  DEFINE_flag(int16_t, name, \0, default_value, help_str)
+  DEFINE_flag(int16_t, name, \0, default_value, help_str, true)
 
 /**
  * @brief Create a new int16_t flag with a long and short name
@@ -248,10 +296,11 @@ void ParseFlags(int *argc, char **argv);
  * @param short_opt the short name of the flag. For example "-h", or "-d".
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_s_int16(name, short_opt, default_value, help_str) \
-  DEFINE_flag_with_short(int16_t, name, short_opt, default_value, help_str)
+  DEFINE_flag_with_short(int16_t, name, short_opt, default_value, help_str, \
+                         true)
 
 
 /**
@@ -259,10 +308,10 @@ void ParseFlags(int *argc, char **argv);
  * @param name the name of the flag to create
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_uint16(name, default_value, help_str) \
-  DEFINE_flag(uint16_t, name, \0, default_value, help_str)
+  DEFINE_flag(uint16_t, name, \0, default_value, help_str, true)
 
 /**
  * @brief Create a new uint16_t flag with a long and short name
@@ -270,20 +319,21 @@ void ParseFlags(int *argc, char **argv);
  * @param short_opt the short name of the flag. For example "-h", or "-d".
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_s_uint16(name, short_opt, default_value, help_str) \
-  DEFINE_flag_with_short(uint16_t, name, short_opt, default_value, help_str)
+  DEFINE_flag_with_short(uint16_t, name, short_opt, default_value, help_str, \
+                         true)
 
 /**
  * @brief Create a new longname int32_t flag
  * @param name the name of the flag to create
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_int32(name, default_value, help_str) \
-  DEFINE_flag(int32_t, name, \0, default_value, help_str)
+  DEFINE_flag(int32_t, name, \0, default_value, help_str, true)
 
 /**
  * @brief Create a new int32_t flag with a long and short name
@@ -291,20 +341,21 @@ void ParseFlags(int *argc, char **argv);
  * @param short_opt the short name of the flag. For example "-h", or "-d".
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_s_int32(name, short_opt, default_value, help_str) \
-  DEFINE_flag_with_short(int32_t, name, short_opt, default_value, help_str)
+  DEFINE_flag_with_short(int32_t, name, short_opt, default_value, help_str, \
+                         true)
 
 /**
  * @brief Create a new longname uint32_t flag
  * @param name the name of the flag to create
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_uint32(name, default_value, help_str) \
-  DEFINE_flag(uint32_t, name, \0, default_value, help_str)
+  DEFINE_flag(uint32_t, name, \0, default_value, help_str, true)
 
 /**
  * @brief Create a new int32_t flag with a long and short name
@@ -312,20 +363,21 @@ void ParseFlags(int *argc, char **argv);
  * @param short_opt the short name of the flag. For example "-h", or "-d".
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_s_uint32(name, short_opt, default_value, help_str) \
-  DEFINE_flag_with_short(uint32_t, name, short_opt, default_value, help_str)
+  DEFINE_flag_with_short(uint32_t, name, short_opt, default_value, help_str, \
+                         true)
 
 /**
  * @brief Create a new longname string flag
  * @param name the name of the flag to create
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_string(name, default_value, help_str) \
-  DEFINE_flag(std::string, name, \0, default_value, help_str)
+  DEFINE_flag(std::string, name, \0, default_value, help_str, true)
 
 /**
  * @brief Create a new string flag with a long and short name
@@ -333,10 +385,11 @@ void ParseFlags(int *argc, char **argv);
  * @param short_opt the short name of the flag. For example "-h", or "-d".
  * @param default_value the default value for the flag.
  * @param help_str the string displayed when the program is asked to display
- * the help screen
+ *     the help screen
  */
 #define DEFINE_s_string(name, short_opt, default_value, help_str) \
-  DEFINE_flag_with_short(std::string, name, short_opt, default_value, help_str)
+  DEFINE_flag_with_short(std::string, name, short_opt, default_value, \
+                         help_str, true)
 
 /** @}*/
 
