@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
  *
  * Random.h
  * A simple random number generator.
@@ -21,15 +21,6 @@
 #ifndef INCLUDE_OLA_MATH_RANDOM_H_
 #define INCLUDE_OLA_MATH_RANDOM_H_
 
-#include <ola/io/InputBuffer.h>
-#include <ola/io/OutputBuffer.h>
-#include <stdint.h>
-#include <sys/uio.h>
-#include <deque>
-#include <iostream>
-#include <queue>
-#include <string>
-
 namespace ola {
 namespace math {
 
