@@ -513,6 +513,13 @@ typedef enum {
   SD_COLOR_CORRECTION = 0x0208,
   SD_COLOR_SCROLL = 0x0209,
   SD_COLOR_SEMAPHORE = 0x0210,
+  SD_COLOR_ADD_AMBER = 0x0211,
+  SD_COLOR_ADD_WHITE = 0x0212,
+  SD_COLOR_ADD_WARM_WHITE = 0x0213,
+  SD_COLOR_ADD_COOL_WHITE = 0x0214,
+  SD_COLOR_SUB_UV = 0x0215,
+  SD_COLOR_HUE = 0x0216,
+  SD_COLOR_SATURATION = 0x0217,
   SD_STATIC_GOBO_WHEEL = 0x0301,
   SD_ROTO_GOBO_WHEEL = 0x0302,
   SD_PRISM_WHEEL = 0x0303,
@@ -680,7 +687,7 @@ typedef enum {
 static const uint8_t MAX_RDM_HOSTNAME_LENGTH = 63;
 static const uint8_t MAX_RDM_DOMAIN_NAME_LENGTH = 231;
 
-static const int16_t DNS_NAME_SERVER_MAX_INDEX = 2;
+static const uint8_t DNS_NAME_SERVER_MAX_INDEX = 2;
 }  // namespace rdm
 }  // namespace ola
 #endif  // INCLUDE_OLA_RDM_RDMENUMS_H_
