@@ -183,12 +183,12 @@ class ArtNetNodeImpl::InputPort {
 
 /*
  * Create a new node
- * @param interface the interface to use.
+ * @param iface the interface to use.
  * @param short_name the short node name
  * @param long_name the long node name
  * @param subnet_address the ArtNet 'subnet' address, 4 bits.
  */
-ArtNetNodeImpl::ArtNetNodeImpl(const ola::network::Interface &interface,
+ArtNetNodeImpl::ArtNetNodeImpl(const ola::network::Interface &iface,
                                ola::io::SelectServerInterface *ss,
                                const ArtNetNodeOptions &options,
                                ola::network::UDPSocketInterface *socket)
@@ -203,7 +203,7 @@ ArtNetNodeImpl::ArtNetNodeImpl(const ola::network::Interface &interface,
       m_always_broadcast(options.always_broadcast),
       m_use_limited_broadcast_address(options.use_limited_broadcast_address),
       m_in_configuration_mode(false),
-      m_interface(interface),
+      m_interface(iface),
       m_socket(socket) {
 
   if (!m_socket.get())
@@ -963,14 +963,14 @@ bool ArtNetNodeImpl::SendTimeCode(const ola::timecode::TimeCode &timecode) {
 void ArtNetNodeImpl::SocketReady() {
   artnet_packet packet;
   ssize_t packet_size = sizeof(packet);
-  ola::network::IPV4Address source;
+  ola::network::IPV4SocketAddress source;
 
   if (!m_socket->RecvFrom(reinterpret_cast<uint8_t*>(&packet),
                           &packet_size,
-                          source))
+                          &source))
     return;
 
-  HandlePacket(source, packet, packet_size);
+  HandlePacket(source.Host(), packet, packet_size);
 }
 
 
@@ -1616,8 +1616,7 @@ bool ArtNetNodeImpl::SendPacket(const artnet_packet &packet,
   unsigned int bytes_sent = m_socket->SendTo(
       reinterpret_cast<const uint8_t*>(&packet),
       size,
-      ip_destination,
-      ARTNET_PORT);
+      IPV4SocketAddress(ip_destination, ARTNET_PORT));
 
   if (bytes_sent != size) {
     OLA_INFO << "Only sent " << bytes_sent << " of " << size;
@@ -2021,11 +2020,11 @@ void ArtNetNodeImpl::ReleaseDiscoveryLock(InputPort *port) {
 /**
  * DmxTriWidget Constructor
  */
-ArtNetNode::ArtNetNode(const ola::network::Interface &interface,
+ArtNetNode::ArtNetNode(const ola::network::Interface &iface,
                        ola::io::SelectServerInterface *ss,
                        const ArtNetNodeOptions &options,
                        ola::network::UDPSocketInterface *socket):
-    m_impl(interface, ss, options, socket) {
+    m_impl(iface, ss, options, socket) {
   for (unsigned int i = 0; i < options.input_port_count; i++) {
     ArtNetNodeImplRDMWrapper *wrapper = new ArtNetNodeImplRDMWrapper(&m_impl,
                                                                      i);
