@@ -11,12 +11,12 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  *
  * DummyPort.cpp
  * The Dummy Port for ola
- * Copyright (C) 2005-2008 Simon Newton
+ * Copyright (C) 2005 Simon Newton
  */
 
 #include <iostream>
@@ -48,8 +48,8 @@ using ola::rdm::RDMDiscoveryCallback;
 using ola::rdm::UID;
 using std::auto_ptr;
 using std::map;
+using std::ostringstream;
 using std::string;
-using std::stringstream;
 using std::vector;
 
 
@@ -126,7 +126,7 @@ bool DummyPort::WriteDMX(const DmxBuffer &buffer,
                          uint8_t priority) {
   (void) priority;
   m_buffer = buffer;
-  stringstream str;
+  ostringstream str;
   string data = buffer.Get();
 
   str << "Dummy port: got " << buffer.Size() << " bytes: ";
