@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * OSCDevice.cpp
  * The OSC Device.
@@ -26,6 +26,14 @@
 #include "plugins/osc/OSCDevice.h"
 #include "plugins/osc/OSCPort.h"
 
+// Some preprocessor magic to reduce Windows.h namespace pollution
+#ifdef _WIN32
+#ifdef AddPort
+#undef AddPort
+#define AddPort
+#endif
+#endif
+
 namespace ola {
 namespace plugin {
 namespace osc {
