@@ -99,7 +99,12 @@ SPIDevice::SPIDevice(SPIPlugin *owner,
   }
 
   for (uint8_t i = 0; i < port_count; i++) {
-    SPIOutput::Options spi_output_options(i);
+    SPIOutput::Options spi_output_options(i, m_spi_device_name);
+
+    if (m_preferences->HasKey(DeviceLabelKey(i))) {
+      spi_output_options.device_label =
+          m_preferences->GetValue(DeviceLabelKey(i));
+    }
 
     uint8_t pixel_count;
     if (StringToInt(m_preferences->GetValue(PixelCountKey(i)), &pixel_count)) {
@@ -158,6 +163,7 @@ void SPIDevice::PrePortStop() {
   SPIPorts::iterator iter = m_spi_ports.begin();
   for (uint8_t i = 0; iter != m_spi_ports.end(); iter++, i++) {
     ostringstream str;
+    m_preferences->SetValue(DeviceLabelKey(i), (*iter)->GetDeviceLabel());
     str << static_cast<int>((*iter)->GetPersonality());
     m_preferences->SetValue(PersonalityKey(i), str.str());
     str.str("");
@@ -194,6 +200,10 @@ string SPIDevice::GPIOPinKey() const {
   return m_spi_device_name + "-gpio-pin";
 }
 
+string SPIDevice::DeviceLabelKey(uint8_t port) const {
+  return GetPortKey("device-label", port);
+}
+
 string SPIDevice::PersonalityKey(uint8_t port) const {
   return GetPortKey("personality", port);
 }
