@@ -107,7 +107,7 @@ const ola::rdm::ResponderOps<SPIOutput>::ParamHandler
     NULL},
   { ola::rdm::PID_DEVICE_LABEL,
     &SPIOutput::GetDeviceLabel,
-    NULL},
+    &SPIOutput::SetDeviceLabel},
   { ola::rdm::PID_SOFTWARE_VERSION_LABEL,
     &SPIOutput::GetSoftwareVersionLabel,
     NULL},
@@ -144,6 +144,7 @@ SPIOutput::SPIOutput(const UID &uid, SPIBackendInterface *backend,
       m_output_number(options.output_number),
       m_uid(uid),
       m_pixel_count(options.pixel_count),
+      m_device_label(options.device_label),
       m_start_address(1),
       m_identify_mode(false) {
   m_spi_device_name = FilenameFromPathOrPath(m_backend->DevicePath());
@@ -181,6 +182,15 @@ SPIOutput::~SPIOutput() {
 }
 
 
+string SPIOutput::GetDeviceLabel() const {
+  return m_device_label;
+}
+
+bool SPIOutput::SetDeviceLabel(const string &device_label) {
+  m_device_label = device_label;
+  return true;
+}
+
 uint8_t SPIOutput::GetPersonality() const {
   return m_personality_manager->ActivePersonalityNumber();
 }
@@ -452,7 +462,7 @@ uint8_t SPIOutput::P9813CreateFlag(uint8_t red, uint8_t green, uint8_t blue) {
 const RDMResponse *SPIOutput::GetDeviceInfo(const RDMRequest *request) {
   return ResponderHelper::GetDeviceInfo(
       request, ola::rdm::OLA_SPI_DEVICE_MODEL,
-      ola::rdm::PRODUCT_CATEGORY_FIXTURE, 2,
+      ola::rdm::PRODUCT_CATEGORY_FIXTURE, 3,
       m_personality_manager.get(),
       m_start_address,
       0, m_sensors.size());
@@ -479,7 +489,11 @@ const RDMResponse *SPIOutput::GetManufacturerLabel(
 }
 
 const RDMResponse *SPIOutput::GetDeviceLabel(const RDMRequest *request) {
-  return ResponderHelper::GetString(request, "SPI Device");
+  return ResponderHelper::GetString(request, m_device_label);
+}
+
+const RDMResponse *SPIOutput::SetDeviceLabel(const RDMRequest *request) {
+  return ResponderHelper::SetString(request, &m_device_label);
 }
 
 const RDMResponse *SPIOutput::GetSoftwareVersionLabel(
