@@ -11,7 +11,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * DmxTriWidget.h
  * The Jese DMX-TRI/RDM-TRI widget.
@@ -112,7 +112,7 @@ class DmxTriWidgetImpl: public BaseUsbProWidget,
     void HandleMessage(uint8_t label,
                        const uint8_t *data,
                        unsigned int length);
-    void SendDiscoveryStart();
+    void SendDiscoveryAuto();
     void SendDiscoveryStat();
     void FetchNextUID();
     bool IsDUBRequest(const ola::rdm::RDMRequest *request);
