@@ -67,7 +67,17 @@ class DmxterWidgetTest: public CommonWidgetTest {
   auto_ptr<ola::plugin::usbpro::DmxterWidget> m_widget;
   unsigned int m_tod_counter;
 
-  void Terminate() { m_ss.Terminate(); }
+  void Terminate() {
+    m_ss.Terminate();
+  }
+
+  void CloseAndTerminate() {
+    m_ss.RemoveReadDescriptor(&m_descriptor);
+    m_ss.RemoveReadDescriptor(m_other_end.get());
+    m_descriptor.Close();
+    m_other_end->Close();
+    m_ss.Terminate();
+  }
   void ValidateTod(const ola::rdm::UIDSet &uids);
   void ValidateResponse(ola::rdm::rdm_response_code code,
                         const ola::rdm::RDMResponse *response,
@@ -711,6 +721,9 @@ void DmxterWidgetTest::testShutdown() {
   OLA_ASSERT(m_descriptor.ValidReadDescriptor());
   OLA_ASSERT(m_descriptor.ValidWriteDescriptor());
 
+  m_descriptor.SetOnClose(
+      ola::NewSingleCallback(this, &DmxterWidgetTest::CloseAndTerminate));
+
   // now send a valid shutdown message
   m_endpoint->SendUnsolicitedUsbProData(SHUTDOWN_LABEL, NULL, 0);
   m_ss.Run();
