@@ -14,7 +14,7 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  *
  * WidgetDetectorThread.cpp
- * A thread that periodically looks for usb pro devices, and runs the callback
+ * A thread that periodically looks for USB Pro devices, and runs the callback
  * if they are valid widgets.
  * Copyright (C) 2011 Simon Newton
  */
@@ -26,10 +26,11 @@
 
 #include "ola/BaseTypes.h"
 #include "ola/Callback.h"
-#include "ola/Logging.h"
-#include "ola/StringUtils.h"
 #include "ola/file/Util.h"
 #include "ola/io/Descriptor.h"
+#include "ola/Logging.h"
+#include "ola/stl/STLUtils.h"
+#include "ola/StringUtils.h"
 #include "plugins/usbpro/ArduinoWidget.h"
 #include "plugins/usbpro/BaseUsbProWidget.h"
 #include "plugins/usbpro/DmxTriWidget.h"
@@ -132,18 +133,15 @@ void *WidgetDetectorThread::Run() {
       ola::NewSingleCallback(this, &WidgetDetectorThread::MarkAsRunning));
   m_ss.Run();
 
-  vector<WidgetDetectorInterface*>::const_iterator iter =
-  m_widget_detectors.begin();
-  for (; iter != m_widget_detectors.end(); ++iter)
-    // this will trigger a call to InternalFreeWidget for any remaining widgets
-    delete *iter;
+  // This will trigger a call to InternalFreeWidget for any remaining widgets
+  STLDeleteElements(&m_widget_detectors);
 
   if (!m_active_descriptors.empty())
     OLA_WARN << m_active_descriptors.size() << " are still active";
 
-  ActiveDescriptors::const_iterator iter2 = m_active_descriptors.begin();
-  for (; iter2 != m_active_descriptors.end(); ++iter2) {
-    OLA_INFO  << iter2->first;
+  ActiveDescriptors::const_iterator iter = m_active_descriptors.begin();
+  for (; iter != m_active_descriptors.end(); ++iter) {
+    OLA_INFO  << iter->first;
   }
   m_widget_detectors.clear();
   return NULL;
@@ -161,10 +159,12 @@ bool WidgetDetectorThread::Join(void *ptr) {
 
 /**
  * Indicate that this widget is no longer is use and can be deleted.
- * This can be called from any thread.
  */
 void WidgetDetectorThread::FreeWidget(SerialWidgetInterface *widget) {
+  // We have to remove the descriptor from the ss before closing.
   m_other_ss->RemoveReadDescriptor(widget->GetDescriptor());
+  widget->GetDescriptor()->Close();
+
   m_ss.Execute(
       ola::NewSingleCallback(this,
                              &WidgetDetectorThread::InternalFreeWidget,
@@ -202,8 +202,7 @@ bool WidgetDetectorThread::RunScan() {
       continue;
 
     OLA_INFO << "Found potential USB Serial device at " << *it;
-    ConnectedDescriptor *descriptor =
-      BaseUsbProWidget::OpenDevice(*it);
+    ConnectedDescriptor *descriptor = BaseUsbProWidget::OpenDevice(*it);
     if (!descriptor)
       continue;
 
@@ -213,9 +212,8 @@ bool WidgetDetectorThread::RunScan() {
   return true;
 }
 
-
 /**
- * Start the discovery sequence for a descriptor.
+ * Start the discovery sequence for a widget.
  */
 void WidgetDetectorThread::PerformDiscovery(const string &path,
                                             ConnectedDescriptor *descriptor) {
@@ -224,7 +222,6 @@ void WidgetDetectorThread::PerformDiscovery(const string &path,
   PerformNextDiscoveryStep(descriptor);
 }
 
-
 /**
  * Called when a new widget becomes ready. Ownership of both objects transferrs
  * to use.
@@ -387,8 +384,10 @@ void WidgetDetectorThread::PerformNextDiscoveryStep(
  */
 void WidgetDetectorThread::InternalFreeWidget(SerialWidgetInterface *widget) {
   ConnectedDescriptor *descriptor = widget->GetDescriptor();
-  // remove descriptor from our ss if it's there
-  m_ss.RemoveReadDescriptor(descriptor);
+  // remove descriptor from our ss if it's still there
+  if (descriptor->ValidReadDescriptor()) {
+    m_ss.RemoveReadDescriptor(descriptor);
+  }
   delete widget;
   FreeDescriptor(descriptor);
 }
