@@ -315,6 +315,13 @@ SLOT_DEFINITIONS = {
   'SD_COLOR_CORRECTION': 0x0208,
   'SD_COLOR_SCROLL': 0x0209,
   'SD_COLOR_SEMAPHORE': 0x0210,
+  'SD_COLOR_ADD_AMBER': 0x0211,
+  'SD_COLOR_ADD_WHITE': 0x0212,
+  'SD_COLOR_ADD_WARM_WHITE': 0x0213,
+  'SD_COLOR_ADD_COOL_WHITE': 0x0214,
+  'SD_COLOR_SUB_UV': 0x0215,
+  'SD_COLOR_HUE': 0x0216,
+  'SD_COLOR_SATURATION': 0x0217,
   'SD_STATIC_GOBO_WHEEL': 0x0301,
   'SD_ROTO_GOBO_WHEEL': 0x0302,
   'SD_PRISM_WHEEL': 0x0303,
