@@ -65,8 +65,8 @@ DEFINE_s_string(target, t, "", "List of IPs to connect to, overrides SLP");
 DEFINE_string(listen_ip, "", "The IP address to listen on");
 DEFINE_s_string(pid_location, p, "",
                 "The directory to read PID definitiions from");
-DEFINE_s_bool(set, s, false, "Perform a SET (default is GET)");
-DEFINE_bool(list_pids, false, "Display a list of pids");
+DEFINE_s_default_bool(set, s, false, "Perform a SET (default is GET)");
+DEFINE_default_bool(list_pids, false, "Display a list of pids");
 DEFINE_s_string(uid, u, "", "The UID of the device to control.");
 
 using ola::NewCallback;
