@@ -84,7 +84,7 @@
 
 
 /* Copy the first part of user declarations.  */
-#line 1 "./config.ypp"
+#line 1 "./tools/ola_trigger/config.ypp"
 
 #include <string>
 #include <utility>
@@ -117,7 +117,7 @@ int yylex(void);
 
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
 typedef union YYSTYPE
-#line 13 "./config.ypp"
+#line 13 "./tools/ola_trigger/config.ypp"
 {
   unsigned int int_val;
   std::string *str_val;
@@ -128,7 +128,7 @@ typedef union YYSTYPE
   std::pair<Action*, Action*> *action_pair;
 }
 /* Line 193 of yacc.c.  */
-#line 132 "config.tab.cpp"
+#line 132 "tools/ola_trigger/config.tab.cpp"
 	YYSTYPE;
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
@@ -141,7 +141,7 @@ typedef union YYSTYPE
 
 
 /* Line 216 of yacc.c.  */
-#line 145 "config.tab.cpp"
+#line 145 "tools/ola_trigger/config.tab.cpp"
 
 #ifdef short
 # undef short
@@ -1372,12 +1372,12 @@ yyreduce:
   switch (yyn)
     {
         case 6:
-#line 56 "./config.ypp"
+#line 56 "./tools/ola_trigger/config.ypp"
     { SetDefaultValue((yyvsp[(1) - (1)].str_list)); ;}
     break;
 
   case 8:
-#line 61 "./config.ypp"
+#line 61 "./tools/ola_trigger/config.ypp"
     {
         (yyval.str_list) = new std::vector<std::string>;
         (yyval.str_list)->push_back(*(yyvsp[(1) - (5)].str_val));
@@ -1388,7 +1388,7 @@ yyreduce:
     break;
 
   case 13:
-#line 81 "./config.ypp"
+#line 81 "./tools/ola_trigger/config.ypp"
     {
         if ((yyvsp[(3) - (5)].interval_list) == NULL) {
           SetDefaultAction((yyvsp[(1) - (5)].int_val), (yyvsp[(5) - (5)].action_pair)->first, (yyvsp[(5) - (5)].action_pair)->second);
@@ -1400,74 +1400,74 @@ yyreduce:
     break;
 
   case 14:
-#line 92 "./config.ypp"
+#line 92 "./tools/ola_trigger/config.ypp"
     { (yyval.interval_list) = NULL; ;}
     break;
 
   case 15:
-#line 93 "./config.ypp"
+#line 93 "./tools/ola_trigger/config.ypp"
     { (yyval.interval_list) = (yyvsp[(1) - (1)].interval_list); ;}
     break;
 
   case 16:
-#line 97 "./config.ypp"
+#line 97 "./tools/ola_trigger/config.ypp"
     { (yyval.interval_list) = new IntervalList(); (yyval.interval_list)->push_back((yyvsp[(1) - (1)].interval)); ;}
     break;
 
   case 17:
-#line 98 "./config.ypp"
+#line 98 "./tools/ola_trigger/config.ypp"
     { (yyval.interval_list) = (yyvsp[(1) - (3)].interval_list); (yyval.interval_list)->push_back((yyvsp[(3) - (3)].interval)); ;}
     break;
 
   case 18:
-#line 102 "./config.ypp"
+#line 102 "./tools/ola_trigger/config.ypp"
     { (yyval.interval) = CreateInterval((yyvsp[(1) - (1)].int_val), (yyvsp[(1) - (1)].int_val)); ;}
     break;
 
   case 19:
-#line 103 "./config.ypp"
+#line 103 "./tools/ola_trigger/config.ypp"
     { (yyval.interval) = CreateInterval((yyvsp[(1) - (3)].int_val), (yyvsp[(3) - (3)].int_val)); ;}
     break;
 
   case 20:
-#line 107 "./config.ypp"
+#line 107 "./tools/ola_trigger/config.ypp"
     { (yyval.action_pair) = new ActionPair((yyvsp[(1) - (1)].action), (yyvsp[(1) - (1)].action)); ;}
     break;
 
   case 21:
-#line 108 "./config.ypp"
+#line 108 "./tools/ola_trigger/config.ypp"
     { (yyval.action_pair) = new ActionPair(NULL, (yyvsp[(1) - (1)].action)); ;}
     break;
 
   case 22:
-#line 109 "./config.ypp"
+#line 109 "./tools/ola_trigger/config.ypp"
     {
         (yyval.action_pair) = new std::pair<Action*, Action*>((yyvsp[(2) - (3)].action), (yyvsp[(3) - (3)].action));
       ;}
     break;
 
   case 23:
-#line 115 "./config.ypp"
+#line 115 "./tools/ola_trigger/config.ypp"
     { (yyval.action) = (yyvsp[(2) - (2)].action); ;}
     break;
 
   case 24:
-#line 119 "./config.ypp"
+#line 119 "./tools/ola_trigger/config.ypp"
     { (yyval.action) = NULL; ;}
     break;
 
   case 25:
-#line 120 "./config.ypp"
+#line 120 "./tools/ola_trigger/config.ypp"
     { (yyval.action) = (yyvsp[(2) - (2)].action); ;}
     break;
 
   case 26:
-#line 124 "./config.ypp"
+#line 124 "./tools/ola_trigger/config.ypp"
     { (yyval.action) = CreateAssignmentAction((yyvsp[(1) - (1)].str_list)); ;}
     break;
 
   case 27:
-#line 125 "./config.ypp"
+#line 125 "./tools/ola_trigger/config.ypp"
     {
         (yyval.action) = CreateCommandAction(*(yyvsp[(2) - (4)].str_val), (yyvsp[(3) - (4)].str_list));
         delete (yyvsp[(2) - (4)].str_val);
@@ -1475,12 +1475,12 @@ yyreduce:
     break;
 
   case 28:
-#line 132 "./config.ypp"
+#line 132 "./tools/ola_trigger/config.ypp"
     { (yyval.str_list) = new std::vector<std::string>(); ;}
     break;
 
   case 29:
-#line 133 "./config.ypp"
+#line 133 "./tools/ola_trigger/config.ypp"
     {
         (yyval.str_list) = (yyvsp[(1) - (3)].str_list); (yyval.str_list)->push_back(std::string(*(yyvsp[(3) - (3)].str_val)));
         delete (yyvsp[(3) - (3)].str_val);
@@ -1488,12 +1488,12 @@ yyreduce:
     break;
 
   case 34:
-#line 150 "./config.ypp"
+#line 150 "./tools/ola_trigger/config.ypp"
     { (yyval.str_val) = new std::string("/"); (yyval.str_val)->append(*(yyvsp[(2) - (2)].str_val)); ;}
     break;
 
   case 35:
-#line 151 "./config.ypp"
+#line 151 "./tools/ola_trigger/config.ypp"
     {
         (yyval.str_val) = new std::string(*(yyvsp[(1) - (3)].str_val));
         (yyval.str_val)->append("/");
@@ -1505,7 +1505,7 @@ yyreduce:
 
 
 /* Line 1267 of yacc.c.  */
-#line 1509 "config.tab.cpp"
+#line 1509 "tools/ola_trigger/config.tab.cpp"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1719,7 +1719,7 @@ yyreturn:
 }
 
 
-#line 160 "./config.ypp"
+#line 160 "./tools/ola_trigger/config.ypp"
 
 extern int column;
 
